**To delete a custom language model**

The following ``delete-language-model`` example deletes a custom language model. ::

    aws transcribe delete-language-model \
        --model-name model-name

This command produces no output.

For more information, see `Improving Domain-Specific Transcription Accuracy with Custom Language Models <https://docs.aws.amazon.com/transcribe/latest/dg/custom-language-models.html>`__ in the *Amazon Transcribe Developer Guide*.